{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for JavaScript React (JSX).
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/javascript-react.xml and 'make bootstrap'.
module Skylighting.Syntax.JavascriptReact (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for JavaScript React (JSX).
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4javascript-react.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIJavascriptReact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\=(?=\\s*/?>)\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQValue\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindEndTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\150(?:(?:\\b[a-zA-Z_\\$]|[^[:ascii:]])(?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?(?:\\b[a-zA-Z_\\$]|[^[:ascii:]])(?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\138\\S+(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|\\S\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClassDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClassDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBClassDeclarationContent\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBClassDeclarationContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBClassDeclarationContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL:\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoTag\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH/>\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL>\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ComponentTagContent\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefaultTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ComponentTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ComponentTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK</\\s*>\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\137</\\s*(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIComponentTagEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultTagContent\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIComponentTagEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIComponentTagEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagFindType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagFindType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL<\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTypeInsideTag\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagNonASCII\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagNonASCII\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\132(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagFindType\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL:\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReact\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefaultTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefaultTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\150(?:(?:\\b[a-zA-Z_\\$]|[^[:ascii:]])(?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?(?:\\b[a-zA-Z_\\$]|[^[:ascii:]])(?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindEvaluatedCode\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\138\\S+(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|\\S\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindTagsInTagContent\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindEntityRefs\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindEvaluatedCode\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL<\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-AngleBracket\NUL{\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-CurlyBracket\NUL[\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTypeInsideTag-SquareBracket\NUL(\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-RoundBracket\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nElementTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nElementTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH/>\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL>\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ElementTagContent\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefaultTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ElementTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ElementTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK</\\s*>\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL4</\\s*((?:[a-z][a-z\\d]*:)?[a-z][a-z\\d]*|(?=[A-Z_\\$]))\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rElementTagEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultTagContent\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rElementTagEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rElementTagEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ElementTagFindType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ElementTagFindType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL<\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTypeInsideTag\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nElementTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nElementTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEvaluatedCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEvaluatedCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBEvaluatedCode-BeforeTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBEvaluatedCode-BeforeTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEvaluatedCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBFindDeclarationsWithNoTags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBFindDeclarationsWithNoTags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4InterfaceDeclaration\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClassDeclaration\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarDeclaration\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarDeclaration\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarDeclaration\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindEndTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindEndTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH/>\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL>\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindEntityRefs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindEntityRefs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$&(?:[a-zA-Z\\d]+|#\\d+|#x[a-fA-F\\d]+);\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindEvaluatedCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1FindEvaluatedCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBEvaluatedCode-BeforeTag\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindTags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindTags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOHZ<(?=\\s*(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?(?:(<(?:\\s*/\\*(?:[^\\*]|\\*+[^/\\*])*\\*+/)*)?(?:\\s*/\\*(?:[^\\*]|\\*+[^/\\*])*\\*+/)*\\s*[\\?,]|(?:/\\*(?:[^\\*]|\\*+[^/\\*])*\\*+/)+(?![\\s<>]|/[>/\\*]|$|[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|\\{)))\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ<\\s*>\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ElementTagContent\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL8<\\s*(?:[a-z][a-z\\d]*:)?[a-z][a-z\\d]*(?=[\\s<>]|/[>/\\*]|$)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ElementTagFindType\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\162<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)(?=[\\s<>]|/[>/\\*]|$)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagFindType\NUL<\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindTagsInTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindTagsInTagContent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ<\\s*>\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ElementTagContent\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL9<\\s*(?=(?:[a-z][a-z\\d]*:)?(?:[a-z][a-z\\d]*)?[^[:ascii:]])\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagNonASCII\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULc<\\s*(?:[a-z][a-z\\d]*:)?[a-z][a-z\\d]*(?=[^\\w\\$\\-\\.:]|$|[\\-\\.]+(?:[^\\w\\$\\-\\.]|$)|:(?:[^a-zA-Z_\\$]|$))\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ElementTagFindType\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\142<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ComponentTagFindType\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCInterfaceContentDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCInterfaceContentDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4InterfaceDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4InterfaceDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCInterfaceContentDeclaration\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\(\\s*(?=<)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\[\\s*(?=<)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\{\\s*<(\\s*/(?![\\*/]))?\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReact\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReact\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL7\\?(?=[^\\{\\}]*[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*\\s*\\:)\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEObject-BeforeTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEObject-BeforeTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3OverwriteJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3OverwriteJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\NUL[\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\142<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\171\\b(?:return|await)\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\DC3\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\166\\b(?:default)\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\v\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\164\\b(?:yield)\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\156\\=>\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\176(?:[,\\=>:\\*\\?]|&&|\\|\\|)\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155\\[\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155\\(\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEObject-BeforeTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\158<\\s*>\\s*(?=<\\s*(?:(?:[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?:)?[a-zA-Z_\\$[:^ascii:]](?:[\\w\\$\\-\\.[:^ascii:]]*[\\w\\$[:^ascii:]])?|>)|/\\*)\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\SOH/*\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBFindDeclarationsWithNoTags\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3OverwriteJavaScript\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH#!\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL}\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQReact\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSubstitution-BeforeTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSubstitution-BeforeTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstitution\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RegExpAfterString\SOH${\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSubstitution-BeforeTag\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTemplate\t\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTypeInsideTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTypeInsideTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fComponentTag\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-AngleBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-AngleBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL>\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-CurlyBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-CurlyBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-RoundBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTypeInsideTag-RoundBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTypeInsideTag-SquareBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTypeInsideTag-SquareBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4DefaultTypeInsideTag\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bValidTag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\s+(?=<|/\\*)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindTags\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aValueDQ\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aValueSQ\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFindEndTag\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\GS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aValueDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aValueDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindEntityRefs\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aValueSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aValueSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindEntityRefs\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarDeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoTag\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL9[a-zA-Z_$[:^ascii:]][\\w$[:^ascii:]]*(?=\\s*(?:[\\?!]\\s*)?:)\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX!?\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNJavaScript React (JSX)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAllComments\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%Nibaldo Gonz\195\161lez (nibgonz@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.jsx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang"
